pub struct DecodeError {
pub column: Cow<'static, str>,
pub expected: &'static str,
pub actual: Cow<'static, str>,
/* private fields */
}Expand description
Row/column decoding failure.
Fields
column: Cow<'static, str>expected: &'static stractual: Cow<'static, str>Implementations
Sourceimpl DecodeError
impl DecodeError
Sourcepub fn with_source(
column: impl Into<Cow<'static, str>>,
expected: &'static str,
actual: impl Into<Cow<'static, str>>,
source: impl Error + Send + Sync + 'static,
) -> BsqlError
pub fn with_source( column: impl Into<Cow<'static, str>>, expected: &'static str, actual: impl Into<Cow<'static, str>>, source: impl Error + Send + Sync + 'static, ) -> BsqlError
Create a decode error with an underlying cause.
Sourcepub fn column_count(expected: usize, actual: usize) -> BsqlError
pub fn column_count(expected: usize, actual: usize) -> BsqlError
Create a decode error for a column count mismatch.
Used by generated code to detect schema drift between compile-time and runtime (e.g. a column was added/removed after the binary was built).