pub struct Transaction { /* private fields */ }Expand description
A database transaction.
Created by Pool::begin(). Must be explicitly
committed via commit(). If dropped without
commit(), the connection is discarded from the pool.
Implementations
Sourceimpl Transaction
impl Transaction
Sourcepub async fn commit(self) -> BsqlResult<()>
pub async fn commit(self) -> BsqlResult<()>
Commit the transaction and return the connection to the pool.
Consumes self — the transaction cannot be used after commit.
Sourcepub async fn rollback(self) -> BsqlResult<()>
pub async fn rollback(self) -> BsqlResult<()>
Explicitly roll back the transaction and return the connection to the pool.
Consumes self — the transaction cannot be used after rollback.